==> haskell-sendfile-0.7.11.6-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sendfile
version:              0.7.11.6
visibility:           public
id:                   sendfile-0.7.11.6-7g5J1fuHNkFLBDKFudGXRr
key:                  sendfile-0.7.11.6-7g5J1fuHNkFLBDKFudGXRr
license:              BSD-3-Clause
maintainer:           Jeremy Shaw <jeremy@n-heptane.com>
author:               Matthew Elder <matt@mattelder.org>
stability:            provisional
homepage:             https://github.com/Happstack/sendfile
synopsis:             A portable sendfile library
description:
    A library which exposes zero-copy sendfile functionality in a portable way. If a platform does not support sendfile, a fallback implementation in haskell is provided.

    Currently supported platforms: Windows 2000+ (Native), Linux 2.6+ (Native), FreeBSD (Native), OS-X 10.5+ (Native), Everything else (Portable Haskell code).

category:             Network
abi:                  0fd67aa4867fc98b2d9b05ab2809bab3
exposed:              True
exposed-modules:
    Network.Socket.SendFile Network.Socket.SendFile.Handle
    Network.Socket.SendFile.Iter Network.Socket.SendFile.Portable

hidden-modules:
    Network.Socket.SendFile.Internal Network.Socket.SendFile.Util
    Network.Socket.SendFile.Linux

import-dirs:          /usr/lib/ghc-9.4.8/site-local/sendfile-0.7.11.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sendfile-0.7.11.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sendfile-0.7.11.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sendfile
hs-libraries:         HSsendfile-0.7.11.6-7g5J1fuHNkFLBDKFudGXRr
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-7d91dIi13MzEkgRQe6YDcO

haddock-interfaces:   /usr/share/doc/haskell-sendfile/html/sendfile.haddock
haddock-html:         /usr/share/doc/haskell-sendfile/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sendfile-0.7.11.6-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sendfile
version:              0.7.11.6
visibility:           public
id:                   sendfile-0.7.11.6-DELbkgU1a9a11T8ovnNN2f
key:                  sendfile-0.7.11.6-DELbkgU1a9a11T8ovnNN2f
license:              BSD-3-Clause
maintainer:           Jeremy Shaw <jeremy@n-heptane.com>
author:               Matthew Elder <matt@mattelder.org>
stability:            provisional
homepage:             https://github.com/Happstack/sendfile
synopsis:             A portable sendfile library
description:
    A library which exposes zero-copy sendfile functionality in a portable way. If a platform does not support sendfile, a fallback implementation in haskell is provided.

    Currently supported platforms: Windows 2000+ (Native), Linux 2.6+ (Native), FreeBSD (Native), OS-X 10.5+ (Native), Everything else (Portable Haskell code).

category:             Network
abi:                  d670027657a189b84a35323b378ba223
exposed:              True
exposed-modules:
    Network.Socket.SendFile Network.Socket.SendFile.Handle
    Network.Socket.SendFile.Iter Network.Socket.SendFile.Portable

hidden-modules:
    Network.Socket.SendFile.Internal Network.Socket.SendFile.Util
    Network.Socket.SendFile.Linux

import-dirs:          /usr/lib/ghc-9.4.8/site-local/sendfile-0.7.11.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sendfile-0.7.11.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sendfile-0.7.11.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sendfile
hs-libraries:         HSsendfile-0.7.11.6-DELbkgU1a9a11T8ovnNN2f
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-24l6wfZeDaoIo68scGYLPE

haddock-interfaces:   /usr/share/doc/haskell-sendfile/html/sendfile.haddock
haddock-html:         /usr/share/doc/haskell-sendfile/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
